@@ -40,6 +40,11 @@ class Repository:
 
 
 REPOSITORIES = {
+    "aliengo_mj_description": Repository(
+        url="https://github.com/rohanpsingh/aliengo_mj_description.git",
+        commit="15051f23ebec30f8b72ed224d435934f6cbc679f",
+        cache_path="rohanpsingh/aliengo_mj_description",
+    ),
     "anymal_b_simple_description": Repository(
         url="https://github.com/ANYbotics/anymal_b_simple_description.git",
         commit="988b5df22b84761bdf08111b1c2ccc883793f456",
@@ -65,6 +70,11 @@ REPOSITORIES = {
         commit="96323f3d0cc2cb7101cb92d7fcf4650abdcb2e81",
         cache_path="UMich-BipedLab/cassie_description",
     ),
+    "cassie_mj_description": Repository(
+        url="https://github.com/rohanpsingh/cassie_mj_description.git",
+        commit="fcc3775453e4da6797cd4eacd3d8321d9906755a",
+        cache_path="rohanpsingh/cassie_mj_description",
+    ),
     "drake": Repository(
         url="https://github.com/RobotLocomotion/drake.git",
         commit="v1.7.0",
@@ -85,11 +95,21 @@ REPOSITORIES = {
         commit="v1.0.0",
         cache_path="utiasDSL/gym-pybullet-drones",
     ),
+    "icub-models": Repository(
+        url="https://github.com/robotology/icub-models.git",
+        commit="v1.25.0",
+        cache_path="robotology/icub-models",
+    ),
     "jvrc_description": Repository(
         url="https://github.com/stephane-caron/jvrc_description.git",
         commit="v1.1.0",
         cache_path="stephane-caron/jvrc_description",
     ),
+    "jvrc_mj_description": Repository(
+        url="https://github.com/isri-aist/jvrc_mj_description.git",
+        commit="0f0ce7daefdd66c54e0909a6bf2c22154844f5f3",
+        cache_path="isri-aist/jvrc_mj_description",
+    ),
     "mini_cheetah_urdf": Repository(
         url="https://github.com/Derek-TH-Wang/mini_cheetah_urdf.git",
         commit="1988bceb26e81f28594a16e7d5e6abe5cbb27ace",
