@@ -17,20 +17,18 @@
 
 """
 iCub description.
-
-Note:
-    There is some uncertainty around the validity of this model. See
-    https://github.com/clemense/yourdfpy/issues/39
 """
 
 from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-__working_dir__ = _clone_to_cache("example-robot-data")
+REPOSITORY_PATH: str = _clone_to_cache("icub-models")
 
-PATH: str = _path.join(__working_dir__, "robots", "icub_description")
+PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "iCub")
 
-MESHES_PATH: str = _path.join(PATH, "meshes")
+MESHES_PATH: str = _path.join(PACKAGE_PATH, "meshes")
 
-URDF_PATH: str = _path.join(PATH, "robots", "icub.urdf")
+URDF_PATH: str = _path.join(
+    PACKAGE_PATH, "robots", "iCubGazeboV2_5", "model.urdf"
+)
