@@ -23,12 +23,12 @@ from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-__working_dir__ = _clone_to_cache("drake")
+REPOSITORY_PATH: str = _clone_to_cache("drake")
 
-PATH: str = _path.join(
-    __working_dir__, "examples", "pr2", "models", "pr2_description"
+PACKAGE_PATH: str = _path.join(
+    REPOSITORY_PATH, "examples", "pr2", "models", "pr2_description"
 )
 
-MESHES_PATH: str = _path.join(PATH, "meshes")
+MESHES_PATH: str = _path.join(PACKAGE_PATH, "meshes")
 
-URDF_PATH: str = _path.join(PATH, "urdf", "pr2_simplified.urdf")
+URDF_PATH: str = _path.join(PACKAGE_PATH, "urdf", "pr2_simplified.urdf")
