@@ -23,18 +23,18 @@ from os import path as _path
 
 from ._cache import clone_to_cache as _clone_to_cache
 
-__working_dir__ = _clone_to_cache("example-robot-data")
+REPOSITORY_PATH: str = _clone_to_cache("example-robot-data")
 
-PATH: str = _path.join(__working_dir__, "robots", "ur_description")
+PACKAGE_PATH: str = _path.join(REPOSITORY_PATH, "robots", "ur_description")
 
-MESHES_PATH: str = _path.join(PATH, "meshes", "ur3")
+MESHES_PATH: str = _path.join(PACKAGE_PATH, "meshes", "ur3")
 
-URDF_PATH: str = _path.join(PATH, "urdf", "ur3_robot.urdf")
+URDF_PATH: str = _path.join(PACKAGE_PATH, "urdf", "ur3_robot.urdf")
 
 # Description-specific paths
 
-URDF_PATH_GRIPPER: str = _path.join(PATH, "urdf", "ur3_gripper.urdf")
+URDF_PATH_GRIPPER: str = _path.join(PACKAGE_PATH, "urdf", "ur3_gripper.urdf")
 
 URDF_PATH_JOINT_LIMITED: str = _path.join(
-    PATH, "urdf", "ur3_joint_limited_robot.urdf"
+    PACKAGE_PATH, "urdf", "ur3_joint_limited_robot.urdf"
 )
